@@ -71,12 +71,12 @@ class Table(Accessible):
                 @return an Accessible object representing the specified table
                 cell.
                 """
-                func = self.get_dbus_method("getAccessibleAt", dbus_interface=ATSPI_TABLE)
+                func = self.get_dbus_method("GetAccessibleAt", dbus_interface=ATSPI_TABLE)
                 (name, path) = func(row, column)
                 if (name == ""):
                         name = self._app_name
                 return self.acc_factory.create_accessible(name, path,
-                                                          interfaces.ATSPI_ACCESSIBLE)
+                                                          ATSPI_ACCESSIBLE)
 
         def getColumnAtIndex(self, index):
                 """
@@ -127,9 +127,9 @@ class Table(Accessible):
                 @return an Accessible representatin of the specified table column,
                 if available.
                 """
-                func = self.get_dbus_method("getColumnHeader", dbus_interface=ATSPI_TABLE)
+                func = self.get_dbus_method("GetColumnHeader", dbus_interface=ATSPI_TABLE)
                 return self.acc_factory.create_accessible(self._app_name, func(index),
-                                                          interfaces.ATSPI_ACCESSIBLE)
+                                                          ATSPI_ACCESSIBLE)
 
         def getIndexAt(self, row, column):
                 """
@@ -232,9 +232,12 @@ class Table(Accessible):
                 @return an Accessible representatin of the specified table row,
                 if available.
                 """
-                func = self.get_dbus_method("getRowHeader", dbus_interface=ATSPI_TABLE)
-                return self.acc_factory.create_accessible(self._app_name, func(row),
-                                                          interfaces.ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetRowHeader", dbus_interface=ATSPI_TABLE)
+		(name, path) = func (row)
+		if (name == ""):
+			name = self._app_name
+                return self.acc_factory.create_accessible(name, path,
+                                                          ATSPI_ACCESSIBLE)
 
         def getSelectedColumns(self):
                 """
@@ -316,7 +319,7 @@ class Table(Accessible):
                 if (name == ""):
                         name = self._app_name
                 return self.acc_factory.create_accessible(name, path,
-                                                          interfaces.ATSPI_ACCESSIBLE)
+                                                          ATSPI_ACCESSIBLE)
         _captionDoc = \
                 """
                 An Accessible which represents of a caption for a Table.
@@ -367,7 +370,7 @@ class Table(Accessible):
                 if (name == ""):
                         name = self._app_name
                 return self.acc_factory.create_accessible(name, path,
-                                                          interfaces.ATSPI_ACCESSIBLE)
+                                                          ATSPI_ACCESSIBLE)
         _summaryDoc = \
                 """
                 An accessible object which summarizes the contents of a Table.
